Module markdown_parser::adapt[][src]

enable feature adapt to use this module

adapt mod will help to transform the format of a Markdown’s front matters

Structs

CommonObject

the most common format of front matters

EmptyObject

empty object

JsonAdapter

JsonAdapter

SafeObject

the all optional format of front matters

TomlAdapter

TomlAdapter

YamlAdapter

YamlAdapter

Traits

Adapter

MDAdapter trait can transform the format of a Markdown into the given kind

AdapterObject